var plplotluacLUA__wrap_8c =
[
    [ "swig_type_info", "structswig__type__info.html", "structswig__type__info" ],
    [ "swig_cast_info", "structswig__cast__info.html", "structswig__cast__info" ],
    [ "swig_module_info", "structswig__module__info.html", "structswig__module__info" ],
    [ "swig_lua_var_info", "structswig__lua__var__info.html", "structswig__lua__var__info" ],
    [ "swig_lua_const_info", "structswig__lua__const__info.html", "structswig__lua__const__info" ],
    [ "swig_lua_method", "structswig__lua__method.html", "structswig__lua__method" ],
    [ "swig_lua_attribute", "structswig__lua__attribute.html", "structswig__lua__attribute" ],
    [ "swig_lua_namespace", "structswig__lua__namespace.html", "structswig__lua__namespace" ],
    [ "swig_lua_class", "structswig__lua__class.html", "structswig__lua__class" ],
    [ "swig_lua_userdata", "structswig__lua__userdata.html", "structswig__lua__userdata" ],
    [ "swig_lua_rawdata", "structswig__lua__rawdata.html", "structswig__lua__rawdata" ],
    [ "LUA_ALLOC_ARRAY", "plplotluacLUA__wrap_8c.html#ac0ae5db7834185be5a12bc8552aa88a0", null ],
    [ "LUA_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#ac5162a0f31de1371025f827260bd584d", null ],
    [ "LUA_FREE_ARRAY", "plplotluacLUA__wrap_8c.html#ad034efaaaac3076aa497086bf63370af", null ],
    [ "lua_pushglobaltable", "plplotluacLUA__wrap_8c.html#abf88c897458bd9848010301cb46ade18", null ],
    [ "lua_rawlen", "plplotluacLUA__wrap_8c.html#a0a129d773aae7e71b7c30370cd3c3dd9", null ],
    [ "SWIG_AddCast", "plplotluacLUA__wrap_8c.html#a4f6f5e0444e44e48aef51f6620438a5f", null ],
    [ "SWIG_AddNewMask", "plplotluacLUA__wrap_8c.html#af7ac7e424b623712f70e9b6640a54853", null ],
    [ "SWIG_AddTmpMask", "plplotluacLUA__wrap_8c.html#af8527f0123949ec90e05d0fb156c11e3", null ],
    [ "SWIG_ALLOC_ARRAY", "plplotluacLUA__wrap_8c.html#a0fcc00738845cf2e532f6909f27d54d3", null ],
    [ "SWIG_ArgError", "plplotluacLUA__wrap_8c.html#a95bab7504841595502bac5ed195becc1", null ],
    [ "SWIG_BADOBJ", "plplotluacLUA__wrap_8c.html#a8268a243a8a840396db70f745c23c37c", null ],
    [ "SWIG_BUFFER_SIZE", "plplotluacLUA__wrap_8c.html#a26324fcd1baceab72680dfec078da440", null ],
    [ "SWIG_CAST_NEW_MEMORY", "plplotluacLUA__wrap_8c.html#ac8216459bfd45cbd2be36175ef6f1ccc", null ],
    [ "SWIG_CASTRANKLIMIT", "plplotluacLUA__wrap_8c.html#a2f15c36f8b66185937b8232640be62e4", null ],
    [ "SWIG_check_num_args", "plplotluacLUA__wrap_8c.html#a7e3daad25f96879be557754a9e2ed6b4", null ],
    [ "SWIG_CheckState", "plplotluacLUA__wrap_8c.html#a1faed8ca17e98c961611bc35fde708a9", null ],
    [ "SWIG_contract_assert", "plplotluacLUA__wrap_8c.html#aca11636b220cff70dac286c268c95ee6", null ],
    [ "SWIG_ConvertMember", "plplotluacLUA__wrap_8c.html#a019c90e4471fdd37ef65653afe55fb5c", null ],
    [ "SWIG_ConvertPtr", "plplotluacLUA__wrap_8c.html#a3a4e5f587d3994722b0628b2cc96ed42", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#a1955878158ccc192985dc8f572317d2d", null ],
    [ "SWIG_DelNewMask", "plplotluacLUA__wrap_8c.html#ab3ead1d5cb36e1d79daf0bb4732957be", null ],
    [ "SWIG_DelTmpMask", "plplotluacLUA__wrap_8c.html#ac08b44ea4ae9f73b19d915969f301a5d", null ],
    [ "SWIG_DOSTRING_FAIL", "plplotluacLUA__wrap_8c.html#a054a85a15c821ad190018e106214a1ac", null ],
    [ "SWIG_ERROR", "plplotluacLUA__wrap_8c.html#acfa11a770d66f9ca6ba170b173c56c94", null ],
    [ "SWIG_fail", "plplotluacLUA__wrap_8c.html#ababf56889b69e7a569556eb38cd4f157", null ],
    [ "SWIG_fail_arg", "plplotluacLUA__wrap_8c.html#a41cf11e6c8c4513cbca00772e8aef9fd", null ],
    [ "SWIG_fail_ptr", "plplotluacLUA__wrap_8c.html#a2075b3c34e15bf3feb67887a633ccddf", null ],
    [ "SWIG_FREE_ARRAY", "plplotluacLUA__wrap_8c.html#a91259e2a735fab35b6364c5e882e8956", null ],
    [ "SWIG_GetModule", "plplotluacLUA__wrap_8c.html#ab97db3bbfc9e3a73de01e1ee95fa0bb5", null ],
    [ "SWIG_init", "plplotluacLUA__wrap_8c.html#a2d71dac1020240ec6993bfc5048a5988", null ],
    [ "SWIG_init_user", "plplotluacLUA__wrap_8c.html#abff8d88e576deb392ba2834eb7d4ad96", null ],
    [ "SWIG_IsNewObj", "plplotluacLUA__wrap_8c.html#a5246ae38052e6fa0e3cca2026cdda153", null ],
    [ "SWIG_IsOK", "plplotluacLUA__wrap_8c.html#aea8ef410fde907633cb76d9d18131fa1", null ],
    [ "SWIG_isptrtype", "plplotluacLUA__wrap_8c.html#ac24315f20782462ad057bf1c8309a616", null ],
    [ "SWIG_IsTmpObj", "plplotluacLUA__wrap_8c.html#aa8f2563a536468b40dc33843d4bb7efe", null ],
    [ "SWIG_Lua_add_function", "plplotluacLUA__wrap_8c.html#a4e0088e1d53848f80738e5a49f1c0cf3", null ],
    [ "SWIG_LUA_BINARY", "plplotluacLUA__wrap_8c.html#af2062cfc3a6907d38c2587cdab77ae38", null ],
    [ "SWIG_LUA_CHAR", "plplotluacLUA__wrap_8c.html#a50c58df5c9bd1cea902021a7f7fc9896", null ],
    [ "SWIG_LUA_CONSTTAB_CHAR", "plplotluacLUA__wrap_8c.html#af21b898b6e053c8bb73855969e0888b0", null ],
    [ "SWIG_LUA_CONSTTAB_FLOAT", "plplotluacLUA__wrap_8c.html#a86474eb3525b32c80966dde2330e9596", null ],
    [ "SWIG_LUA_CONSTTAB_INT", "plplotluacLUA__wrap_8c.html#a81533fe9e3e23fc8a0caad2a15ddc953", null ],
    [ "SWIG_LUA_CONSTTAB_STRING", "plplotluacLUA__wrap_8c.html#a9bcdad1f49921f12301ceb55b31f7f48", null ],
    [ "SWIG_LUA_FLAVOR_ELUA", "plplotluacLUA__wrap_8c.html#a00a6f75261552001dd1ac741f712d82f", null ],
    [ "SWIG_LUA_FLAVOR_ELUAC", "plplotluacLUA__wrap_8c.html#a351d33087485b24840afe357df576385", null ],
    [ "SWIG_LUA_FLAVOR_LUA", "plplotluacLUA__wrap_8c.html#a6e2b880437634cb73e882be20de53d32", null ],
    [ "SWIG_LUA_FLOAT", "plplotluacLUA__wrap_8c.html#a9c4ea7e25de05f5a501e7163fd480b67", null ],
    [ "SWIG_Lua_get_table", "plplotluacLUA__wrap_8c.html#a45e06ea798b759df9853467b13abcdfc", null ],
    [ "SWIG_LUA_INT", "plplotluacLUA__wrap_8c.html#ae486ba0f8ccf6c87507633344d3f6a96", null ],
    [ "SWIG_LUA_MODULE_GLOBAL", "plplotluacLUA__wrap_8c.html#a9ea8dbda85958ffd0de0a8535b59cc6f", null ],
    [ "SWIG_LUA_POINTER", "plplotluacLUA__wrap_8c.html#a2f4d58f9ce413585253063575c033082", null ],
    [ "SWIG_LUA_STRING", "plplotluacLUA__wrap_8c.html#af6a25edb9ad2ab838e1b1fa3e4450121", null ],
    [ "SWIG_LUA_TARGET", "plplotluacLUA__wrap_8c.html#a84d911ffa9c41b3a66cc7e7d3645671f", null ],
    [ "SWIG_LUACODE", "plplotluacLUA__wrap_8c.html#ae414a798047560c2492aedd86b78beb9", null ],
    [ "SWIG_MangledTypeQuery", "plplotluacLUA__wrap_8c.html#a0ca9dc37d343186a34e966b5a8649ac0", null ],
    [ "SWIG_MODULE_CLIENTDATA_TYPE", "plplotluacLUA__wrap_8c.html#a50d0a80dccc1d34749f07c82d6a04169", null ],
    [ "SWIG_MustGetPtr", "plplotluacLUA__wrap_8c.html#a59f926cc14b21f2e478ac27541df0162", null ],
    [ "SWIG_name", "plplotluacLUA__wrap_8c.html#acff905e8f0880e6e5bba1495c416a6af", null ],
    [ "SWIG_NewMemberObj", "plplotluacLUA__wrap_8c.html#a20c6437f49ae257857683ba0e7b2100f", null ],
    [ "SWIG_NEWOBJ", "plplotluacLUA__wrap_8c.html#ab00ef4fde02a6d8d9653ea9edb28d3c9", null ],
    [ "SWIG_NEWOBJMASK", "plplotluacLUA__wrap_8c.html#a0021b435c31c3ab285b5a6f4547719e3", null ],
    [ "SWIG_NewPointerObj", "plplotluacLUA__wrap_8c.html#a8eb06167550295873af166db6a49cf36", null ],
    [ "SWIG_OK", "plplotluacLUA__wrap_8c.html#af9ecbac56d4c5cd6104ae8f6bb82e9f7", null ],
    [ "SWIG_OLDOBJ", "plplotluacLUA__wrap_8c.html#a4afcf490ff5b4abbca27ca23d9af288e", null ],
    [ "SWIG_POINTER_DISOWN", "plplotluacLUA__wrap_8c.html#aa56139a289829795ed651d533826b65e", null ],
    [ "SWIG_POINTER_OWN", "plplotluacLUA__wrap_8c.html#a1a125b0e9c551bb9cdeb21b8e5be5b57", null ],
    [ "SWIG_RUNTIME_VERSION", "plplotluacLUA__wrap_8c.html#a4895907de5539551925ab5c03ea05d28", null ],
    [ "SWIG_SetModule", "plplotluacLUA__wrap_8c.html#a673a7dcc5c15f5cffa7072785a6c7972", null ],
    [ "SWIG_TMPOBJ", "plplotluacLUA__wrap_8c.html#ab1fe70ae34b39b709eb4cfb084862236", null ],
    [ "SWIG_TMPOBJMASK", "plplotluacLUA__wrap_8c.html#a399dafc6302bd9b309041d5570ae94c9", null ],
    [ "SWIG_TYPE_TABLE_NAME", "plplotluacLUA__wrap_8c.html#ac619a84edecccb5e00c1b4a3180b8c3a", null ],
    [ "SWIG_TypeQuery", "plplotluacLUA__wrap_8c.html#a184d005bbcde85bc7d3f652de20d10b3", null ],
    [ "SWIGEXPORT", "plplotluacLUA__wrap_8c.html#aea3c8b056dcc8c1ab93f6b825cd1371b", null ],
    [ "SWIGINLINE", "plplotluacLUA__wrap_8c.html#a6d0a7c65b3712775e92c8bdb7acdd0ee", null ],
    [ "SWIGINTERN", "plplotluacLUA__wrap_8c.html#a8f2319f775e5b9d5906c9ef25d9b819a", null ],
    [ "SWIGINTERNINLINE", "plplotluacLUA__wrap_8c.html#afc5b08bb3c3cd2e3fb2e34b775346153", null ],
    [ "SWIGLUA", "plplotluacLUA__wrap_8c.html#a2766a62201ede45a8bce1856f083d631", null ],
    [ "SWIGRUNTIME", "plplotluacLUA__wrap_8c.html#a42cd9c1d67d803040a3e78515945afcb", null ],
    [ "SWIGRUNTIMEINLINE", "plplotluacLUA__wrap_8c.html#affa7aa2bcce5bea24a20e5b184ae0533", null ],
    [ "SWIGSTDCALL", "plplotluacLUA__wrap_8c.html#adcd6410456ea7a76147d3ad95b9bcb36", null ],
    [ "SWIGTEMPLATEDISAMBIGUATOR", "plplotluacLUA__wrap_8c.html#a7e84031693895e512662f5b390c6d0e4", null ],
    [ "SWIGTYPE_p_char", "plplotluacLUA__wrap_8c.html#a4fea528f7738d5fc0e2f14911d2b9d38", null ],
    [ "SWIGTYPE_p_double", "plplotluacLUA__wrap_8c.html#ae614b9773454184a45966a0750727b9d", null ],
    [ "SWIGTYPE_p_f_double_double__int", "plplotluacLUA__wrap_8c.html#af0600c84bffb86e3577df30fe36d3425", null ],
    [ "SWIGTYPE_p_f_double_double_p_double_p_double_p_void__void", "plplotluacLUA__wrap_8c.html#a48b31267a66347025b9c355ccfbd54a9", null ],
    [ "SWIGTYPE_p_f_int_double_p_char_int_p_void__void", "plplotluacLUA__wrap_8c.html#ad7e79c86e7c871c2e72af2844fbf46d9", null ],
    [ "SWIGTYPE_p_f_int_p_double_p_double__void", "plplotluacLUA__wrap_8c.html#ae94c3b6e426b2f10008f5a3c2f56af92", null ],
    [ "SWIGTYPE_p_f_int_p_q_const__double_p_q_const__double__void", "plplotluacLUA__wrap_8c.html#a5f4f8d97e6e3d08d8690b7f64d05e93e", null ],
    [ "SWIGTYPE_p_int", "plplotluacLUA__wrap_8c.html#a73413c3e668627181e90558738caccd5", null ],
    [ "SWIGTYPE_p_p_char", "plplotluacLUA__wrap_8c.html#ae62a09763b43a6f895de430344a26b80", null ],
    [ "SWIGTYPE_p_p_double", "plplotluacLUA__wrap_8c.html#a9ca4064d87fbf44deefc2a6a15e6ab2f", null ],
    [ "SWIGTYPE_p_PLGraphicsIn", "plplotluacLUA__wrap_8c.html#a2a00b161b1ee44d933693f234ca003e5", null ],
    [ "SWIGTYPE_p_unsigned_int", "plplotluacLUA__wrap_8c.html#ac97b19aa5dc7dde3dfd22b663edbca22", null ],
    [ "SWIGUNUSED", "plplotluacLUA__wrap_8c.html#a6ee41cd160d397aa76668bf4db65e2d1", null ],
    [ "SWIGUNUSEDPARM", "plplotluacLUA__wrap_8c.html#a6a54164d0685c632e7540c5ad32a453a", null ],
    [ "ct_func", "plplotluacLUA__wrap_8c.html#a595f4b3960322d1991cb097ff49edb3f", null ],
    [ "defined_func", "plplotluacLUA__wrap_8c.html#aead6f867c497426f7186863e3851644f", null ],
    [ "f2eval_func", "plplotluacLUA__wrap_8c.html#a5fe6f22b8e29a47aa53b073eadc90065", null ],
    [ "fill_func", "plplotluacLUA__wrap_8c.html#a18b05e8276c2f5a41addeea4dd595184", null ],
    [ "label_func", "plplotluacLUA__wrap_8c.html#a24e6529701ca8aa4bf683b08b8f8ca3c", null ],
    [ "mapform_func", "plplotluacLUA__wrap_8c.html#aa6d42edeb63fc7047fe2a4b75171afaa", null ],
    [ "pltr_func", "plplotluacLUA__wrap_8c.html#a3c135a6feccda3fdd1146327cab6c7a9", null ],
    [ "swig_cast_info", "plplotluacLUA__wrap_8c.html#a9a04e6e78de723759e5450cd29429d1f", null ],
    [ "swig_converter_func", "plplotluacLUA__wrap_8c.html#a2c314f22b391bfcaff5a11f4b76f66ec", null ],
    [ "swig_dycast_func", "plplotluacLUA__wrap_8c.html#ad9f16e529633c78df7a780b9749395ce", null ],
    [ "swig_lua_class", "plplotluacLUA__wrap_8c.html#a6923d1145cdb4f743ce8082c79172b39", null ],
    [ "swig_module_info", "plplotluacLUA__wrap_8c.html#acf7d83901372902dd5cf59a611dfb320", null ],
    [ "swig_type_info", "plplotluacLUA__wrap_8c.html#a838fee418372997705a565cd6ecd3b22", null ],
    [ "_SWIG_Lua_AddMetatable", "plplotluacLUA__wrap_8c.html#a6a7b2f986ba79897d134b089b7edc482", null ],
    [ "_wrap_abort", "plplotluacLUA__wrap_8c.html#a4e7ebe17427f89ed847e3b90102741a8", null ],
    [ "_wrap_adv", "plplotluacLUA__wrap_8c.html#ac9831c7cbfcc01d54fad00ed69a87bb0", null ],
    [ "_wrap_arc", "plplotluacLUA__wrap_8c.html#aa1c4c2f1061fab1b118c92e66100500a", null ],
    [ "_wrap_axes", "plplotluacLUA__wrap_8c.html#a9bfb3fc63d178b9e60802d89aaf5fa6b", null ],
    [ "_wrap_bin", "plplotluacLUA__wrap_8c.html#ab50028f5a4db6dc07814628d77c7e389", null ],
    [ "_wrap_bop", "plplotluacLUA__wrap_8c.html#ab9e97c6c6ddb646edb14b90e1337e0b8", null ],
    [ "_wrap_box", "plplotluacLUA__wrap_8c.html#a0f2149984bc61ff82ffbe25800f4bf31", null ],
    [ "_wrap_box3", "plplotluacLUA__wrap_8c.html#a70c617b4746a7ddf7f70745e4042e13f", null ],
    [ "_wrap_btime", "plplotluacLUA__wrap_8c.html#ad7b5322311f14f7bf6d079d8d965a3dc", null ],
    [ "_wrap_calc_world", "plplotluacLUA__wrap_8c.html#a5e61a339c4f72d6cc74be10be68510f4", null ],
    [ "_wrap_clear", "plplotluacLUA__wrap_8c.html#a0452dc25d6041031b0174a314c11849b", null ],
    [ "_wrap_col0", "plplotluacLUA__wrap_8c.html#ae8ecc1a5bba2e2678dec6afe9bda58c7", null ],
    [ "_wrap_col1", "plplotluacLUA__wrap_8c.html#ad736ef77af67c8793be6b3f5dfea01d7", null ],
    [ "_wrap_colorbar", "plplotluacLUA__wrap_8c.html#a3d50fd4b06ddf3a3d35bdf79ada59ff5", null ],
    [ "_wrap_configtime", "plplotluacLUA__wrap_8c.html#a0ad1c279fb0619687c8e2192cd309d14", null ],
    [ "_wrap_cont", "plplotluacLUA__wrap_8c.html#a32d804be8a87670a4c7d9d719ccfa2c3", null ],
    [ "_wrap_cpstrm", "plplotluacLUA__wrap_8c.html#aa4756f731862bfcc4a8f421f049056bf", null ],
    [ "_wrap_ctime", "plplotluacLUA__wrap_8c.html#aafa918a459c94156f9074a3a832f5cc3", null ],
    [ "_wrap_env", "plplotluacLUA__wrap_8c.html#a6f26fcca1d4743bb54cf899ed66ade98", null ],
    [ "_wrap_env0", "plplotluacLUA__wrap_8c.html#a20f62cb761c3f64df4ef7734f0b91a83", null ],
    [ "_wrap_eop", "plplotluacLUA__wrap_8c.html#abbbba9274226c1d4c50b9dc1a6227d03", null ],
    [ "_wrap_errx", "plplotluacLUA__wrap_8c.html#a7539f153052d894c22ee69eda8bf6f9d", null ],
    [ "_wrap_erry", "plplotluacLUA__wrap_8c.html#ae01aded943fc1ac76c21983c540e13fb", null ],
    [ "_wrap_famadv", "plplotluacLUA__wrap_8c.html#a687a369b99b42e6e350e9925473f7344", null ],
    [ "_wrap_fill", "plplotluacLUA__wrap_8c.html#ade42fbaaf63b94b8e6df0a3977ea2f36", null ],
    [ "_wrap_fill3", "plplotluacLUA__wrap_8c.html#afd9631c26fbf5e1a82a2ca9378a47729", null ],
    [ "_wrap_flush", "plplotluacLUA__wrap_8c.html#a3dc382edb06265986be8683d9e92d249", null ],
    [ "_wrap_font", "plplotluacLUA__wrap_8c.html#a6a0ad214c627fd588ab96b857e11faa1", null ],
    [ "_wrap_fontld", "plplotluacLUA__wrap_8c.html#a841054245657f57fe9aba8d04bd512b5", null ],
    [ "_wrap_gchr", "plplotluacLUA__wrap_8c.html#a57c135efc76634ec58ea6f45292ea647", null ],
    [ "_wrap_gcmap1_range", "plplotluacLUA__wrap_8c.html#a483556978deba5423c1f1c1271009a60", null ],
    [ "_wrap_gcol0", "plplotluacLUA__wrap_8c.html#ab6cb4076c59bbb9b5d36e5fb76555883", null ],
    [ "_wrap_gcol0a", "plplotluacLUA__wrap_8c.html#ace89625f6b79c62138ba2d99393d648e", null ],
    [ "_wrap_gcolbg", "plplotluacLUA__wrap_8c.html#af4eda63e34afe601431e49c77ab8b75e", null ],
    [ "_wrap_gcolbga", "plplotluacLUA__wrap_8c.html#a21e8e31b95216eb7161d5538c6b0b4a7", null ],
    [ "_wrap_gcompression", "plplotluacLUA__wrap_8c.html#aa629e215577bbd45a49a49e84cbae850", null ],
    [ "_wrap_gdev", "plplotluacLUA__wrap_8c.html#afd43735f1003b553ee8016965ff8e561", null ],
    [ "_wrap_gdidev", "plplotluacLUA__wrap_8c.html#a9b705703dafdfe05a5da0ec9c2e246e4", null ],
    [ "_wrap_gdiori", "plplotluacLUA__wrap_8c.html#a66d7d111be9cbf50162277dcf38bfce4", null ],
    [ "_wrap_gdiplt", "plplotluacLUA__wrap_8c.html#aa5586f943a99365c1b6bbcfd66db2887", null ],
    [ "_wrap_gfam", "plplotluacLUA__wrap_8c.html#a712321d8f9a62e655c27a0c6dc6792c0", null ],
    [ "_wrap_gfci", "plplotluacLUA__wrap_8c.html#aac80a9aa9d37c978edacd2ca1c07e829", null ],
    [ "_wrap_gfnam", "plplotluacLUA__wrap_8c.html#ab4e3d27ddbb541427d46f7253bbc453e", null ],
    [ "_wrap_gfont", "plplotluacLUA__wrap_8c.html#ae9d7063f41b45a03c333b6010237504c", null ],
    [ "_wrap_glevel", "plplotluacLUA__wrap_8c.html#a4f4fe7a673d91b1d1d49cdb62b611cf7", null ],
    [ "_wrap_gpage", "plplotluacLUA__wrap_8c.html#a5a7fba838eaa434d960abd0a64c29623", null ],
    [ "_wrap_gra", "plplotluacLUA__wrap_8c.html#ac9a638a4da0c52f09d2eee7b5d35e0bb", null ],
    [ "_wrap_gradient", "plplotluacLUA__wrap_8c.html#a34aa66d28ea5856a9b7d422d878544f4", null ],
    [ "_wrap_griddata", "plplotluacLUA__wrap_8c.html#ac8b6506c5868810e7c3fe9c230311e71", null ],
    [ "_wrap_gspa", "plplotluacLUA__wrap_8c.html#a3ab7d3df33114a70c52db6209bb87d30", null ],
    [ "_wrap_gstrm", "plplotluacLUA__wrap_8c.html#a780d68efd53897fc8f5a0f4d699d216e", null ],
    [ "_wrap_gver", "plplotluacLUA__wrap_8c.html#a8f28c39704ce6093c9362291bc57e9ff", null ],
    [ "_wrap_gvpd", "plplotluacLUA__wrap_8c.html#a23f0985d434293422fcb4e47172f485f", null ],
    [ "_wrap_gvpw", "plplotluacLUA__wrap_8c.html#a5eedcbe3be0f6294b8627f549f3cc474", null ],
    [ "_wrap_gxax", "plplotluacLUA__wrap_8c.html#a2c00f6735ca2f684945f9d16d4c9106c", null ],
    [ "_wrap_gyax", "plplotluacLUA__wrap_8c.html#a0ef991adca430d4a150402698cde9bf0", null ],
    [ "_wrap_gzax", "plplotluacLUA__wrap_8c.html#a6aba048e424a3de858489f42b07a6cc9", null ],
    [ "_wrap_hist", "plplotluacLUA__wrap_8c.html#a3879719e621767c1eb8ff25452bfefa7", null ],
    [ "_wrap_hlsrgb", "plplotluacLUA__wrap_8c.html#a1e860c3ec3a473d1fd7a99e86e542f9a", null ],
    [ "_wrap_image", "plplotluacLUA__wrap_8c.html#a60f94f24232647524b29f0ee0cf44f06", null ],
    [ "_wrap_imagefr", "plplotluacLUA__wrap_8c.html#a8ecc0549b3d52e07c63481c2ad007b8f", null ],
    [ "_wrap_init", "plplotluacLUA__wrap_8c.html#a7948e8e8cfd60dc80af695cba04ad094", null ],
    [ "_wrap_join", "plplotluacLUA__wrap_8c.html#aa3ef6963789be161edec0537792e852a", null ],
    [ "_wrap_lab", "plplotluacLUA__wrap_8c.html#ad17006e6c90ac20532543bfeff3fc348", null ],
    [ "_wrap_legend", "plplotluacLUA__wrap_8c.html#a86dc8678fd1410a9e75e07c9816fb5b0", null ],
    [ "_wrap_lightsource", "plplotluacLUA__wrap_8c.html#a5d1984012208dbd9e6273da40ea872f2", null ],
    [ "_wrap_line", "plplotluacLUA__wrap_8c.html#a84d6eb100f23f53cf8d92b1b5d3bb33e", null ],
    [ "_wrap_line3", "plplotluacLUA__wrap_8c.html#a98085ca4ca86066c4b8eee25ccbd4bc8", null ],
    [ "_wrap_lsty", "plplotluacLUA__wrap_8c.html#ab3159c1edf08576a7cef1e00d1562e2e", null ],
    [ "_wrap_map", "plplotluacLUA__wrap_8c.html#a70f6fbe3b32794252cee4a9bbe01972e", null ],
    [ "_wrap_mapfill", "plplotluacLUA__wrap_8c.html#a82635b58ada80aeee732178f9623e86e", null ],
    [ "_wrap_mapline", "plplotluacLUA__wrap_8c.html#ab63d650c968d84167ad65199b231c86b", null ],
    [ "_wrap_mapstring", "plplotluacLUA__wrap_8c.html#ad6ba2984c1ac54a5b84d5d383d474ec2", null ],
    [ "_wrap_maptex", "plplotluacLUA__wrap_8c.html#af5eddf160051337c0dce926bf689951a", null ],
    [ "_wrap_meridians", "plplotluacLUA__wrap_8c.html#a201353c8f482b8960dec6f98ece9781d", null ],
    [ "_wrap_mesh", "plplotluacLUA__wrap_8c.html#a0ed87b1f9162641c692d0126a013ea31", null ],
    [ "_wrap_meshc", "plplotluacLUA__wrap_8c.html#aada58c84a8d35fc760881bb2798f1085", null ],
    [ "_wrap_MinMax2dGrid", "plplotluacLUA__wrap_8c.html#a64195ba496d7e6f1e16d44f5d277c3a3", null ],
    [ "_wrap_mkstrm", "plplotluacLUA__wrap_8c.html#a1266391fe28886f20f85da99063619f5", null ],
    [ "_wrap_mtex", "plplotluacLUA__wrap_8c.html#adecf5a5c989d3084d0fce4b687c27b27", null ],
    [ "_wrap_mtex3", "plplotluacLUA__wrap_8c.html#ad7e201577c6a467d8bd54be2c17d44a5", null ],
    [ "_wrap_new_PLGraphicsIn", "plplotluacLUA__wrap_8c.html#a4da24e00b3d5e13b0729d63d7bef7675", null ],
    [ "_wrap_parseopts", "plplotluacLUA__wrap_8c.html#a640189894219f257e0fa8c10d54ae5fc", null ],
    [ "_wrap_pat", "plplotluacLUA__wrap_8c.html#a55d9589c81799b4b1db6313530cb5e2a", null ],
    [ "_wrap_path", "plplotluacLUA__wrap_8c.html#aa99c715845238eb396cd110bded07eb3", null ],
    [ "_wrap_plClearOpts", "plplotluacLUA__wrap_8c.html#a867af8ab2e3fa377a2859285c979d2fd", null ],
    [ "_wrap_plend", "plplotluacLUA__wrap_8c.html#a18c1a0bb80725f4ce8e4b8fd9fa00f1e", null ],
    [ "_wrap_plend1", "plplotluacLUA__wrap_8c.html#a7094ee72c85950d5b3687c28e88afb45", null ],
    [ "_wrap_plGetCursor", "plplotluacLUA__wrap_8c.html#a2a2dc77954a15c605c47fe69fb7b77e3", null ],
    [ "_wrap_PLGraphicsIn_button_get", "plplotluacLUA__wrap_8c.html#a07bda582ca6d4168898a29a964b21bf3", null ],
    [ "_wrap_PLGraphicsIn_button_set", "plplotluacLUA__wrap_8c.html#ad237e355283eab8b502867720a531c21", null ],
    [ "_wrap_PLGraphicsIn_dX_get", "plplotluacLUA__wrap_8c.html#a50fc9f3ce34f71ca1d07f39e78c1c030", null ],
    [ "_wrap_PLGraphicsIn_dX_set", "plplotluacLUA__wrap_8c.html#ab72812a2427bc25bb07ca05ceb68dfe1", null ],
    [ "_wrap_PLGraphicsIn_dY_get", "plplotluacLUA__wrap_8c.html#a94a6139e50e66ac7c5251168d676ed51", null ],
    [ "_wrap_PLGraphicsIn_dY_set", "plplotluacLUA__wrap_8c.html#af6356c4b81973402d6574f1e5dd2c91d", null ],
    [ "_wrap_PLGraphicsIn_keysym_get", "plplotluacLUA__wrap_8c.html#a13259de2c94c097490bc199eadd92c87", null ],
    [ "_wrap_PLGraphicsIn_keysym_set", "plplotluacLUA__wrap_8c.html#a92bf4147110588416475364a57ba54bf", null ],
    [ "_wrap_PLGraphicsIn_pX_get", "plplotluacLUA__wrap_8c.html#ae0bd6709a42bd7b6f26b985d54b65b5a", null ],
    [ "_wrap_PLGraphicsIn_pX_set", "plplotluacLUA__wrap_8c.html#ac2dd1f87b1b4b9f5f90a2620e57cf281", null ],
    [ "_wrap_PLGraphicsIn_pY_get", "plplotluacLUA__wrap_8c.html#a5866282ff3e8314935147900f0e57e0b", null ],
    [ "_wrap_PLGraphicsIn_pY_set", "plplotluacLUA__wrap_8c.html#a2ee7b446a43dce70cb5bfd32d66abe29", null ],
    [ "_wrap_PLGraphicsIn_state_get", "plplotluacLUA__wrap_8c.html#a40c3c73f45238dd9dac3a30f9206e450", null ],
    [ "_wrap_PLGraphicsIn_state_set", "plplotluacLUA__wrap_8c.html#a623a7e2ab7e1ada8004bc26626fd4401", null ],
    [ "_wrap_PLGraphicsIn_string_get", "plplotluacLUA__wrap_8c.html#a6f3c8e1ef48fe42610667adde377998f", null ],
    [ "_wrap_PLGraphicsIn_string_set", "plplotluacLUA__wrap_8c.html#a83096e5100ca6fb7fc658a60e4ee119f", null ],
    [ "_wrap_PLGraphicsIn_subwindow_get", "plplotluacLUA__wrap_8c.html#a172bc605278e46a9c84ebb9b71689257", null ],
    [ "_wrap_PLGraphicsIn_subwindow_set", "plplotluacLUA__wrap_8c.html#aa9eec44a694d512ffec0084988209085", null ],
    [ "_wrap_PLGraphicsIn_type_get", "plplotluacLUA__wrap_8c.html#a9c0f457fbf8b41c463967dfd91fa589a", null ],
    [ "_wrap_PLGraphicsIn_type_set", "plplotluacLUA__wrap_8c.html#aa3b7df6650627a2a128bfd8b9386098c", null ],
    [ "_wrap_PLGraphicsIn_wX_get", "plplotluacLUA__wrap_8c.html#a02359da510d0f78f8be33a06e9cb7ae4", null ],
    [ "_wrap_PLGraphicsIn_wX_set", "plplotluacLUA__wrap_8c.html#ab98d112a8c326422429a985cc5d0f609", null ],
    [ "_wrap_PLGraphicsIn_wY_get", "plplotluacLUA__wrap_8c.html#aaf757ea456013e5e3eb87be947b0943e", null ],
    [ "_wrap_PLGraphicsIn_wY_set", "plplotluacLUA__wrap_8c.html#afb0fd29e0065b7f3c3f78ea9ed87cd08", null ],
    [ "_wrap_plOptUsage", "plplotluacLUA__wrap_8c.html#a5f008f0df1cce7ff1b234c585a2e9136", null ],
    [ "_wrap_plot3d", "plplotluacLUA__wrap_8c.html#a8a124a47d2a704fe93bd06cb2841d32c", null ],
    [ "_wrap_plot3dc", "plplotluacLUA__wrap_8c.html#aae9ae8eb7ae51556bb2c2a9293ba0c69", null ],
    [ "_wrap_plot3dcl", "plplotluacLUA__wrap_8c.html#a5ea1893a4fea5fdefc462316b4a824d3", null ],
    [ "_wrap_plResetOpts", "plplotluacLUA__wrap_8c.html#a5ac7b58218ad09df9586125db25291d7", null ],
    [ "_wrap_plSetUsage", "plplotluacLUA__wrap_8c.html#abeed28e278d5295f08263b91b69830ca", null ],
    [ "_wrap_poin", "plplotluacLUA__wrap_8c.html#a82630f320ac81a290f2d6252846afa17", null ],
    [ "_wrap_poin3", "plplotluacLUA__wrap_8c.html#a89d27f92eadb92116ede6d1a2ed874bd", null ],
    [ "_wrap_poly3", "plplotluacLUA__wrap_8c.html#abfcf180f73f7a0ffdda69e9dafcecca1", null ],
    [ "_wrap_prec", "plplotluacLUA__wrap_8c.html#ac1005278ac0ad6abe5b31b24e5f83fe3", null ],
    [ "_wrap_psty", "plplotluacLUA__wrap_8c.html#a3120e0f5c5e46166850bc2eed4f84ced", null ],
    [ "_wrap_ptex", "plplotluacLUA__wrap_8c.html#a0232f8a620597b73ae817221a3143d43", null ],
    [ "_wrap_ptex3", "plplotluacLUA__wrap_8c.html#abb00f7c2df3de37071bfe44cba235d0f", null ],
    [ "_wrap_randd", "plplotluacLUA__wrap_8c.html#a9eeb676e84a7a9a776a65f84b5e62d1c", null ],
    [ "_wrap_replot", "plplotluacLUA__wrap_8c.html#a7c698538a160c8e55de535b6f1849a36", null ],
    [ "_wrap_rgbhls", "plplotluacLUA__wrap_8c.html#a1761ac03bee5b9180aa98d228141d014", null ],
    [ "_wrap_schr", "plplotluacLUA__wrap_8c.html#af209bcd19b67a1a9802239f685aa8c66", null ],
    [ "_wrap_scmap0", "plplotluacLUA__wrap_8c.html#aedfeda02d3c92e8e930c092d2bd8e5e6", null ],
    [ "_wrap_scmap0a", "plplotluacLUA__wrap_8c.html#a34a2c94fd9447fe5f8e7ddbe9054566d", null ],
    [ "_wrap_scmap0n", "plplotluacLUA__wrap_8c.html#a742283e55502a2a3ed1b21c4a6169f2e", null ],
    [ "_wrap_scmap1", "plplotluacLUA__wrap_8c.html#a0327e4bac0f3ecbb1b12bae2df1fddb8", null ],
    [ "_wrap_scmap1_range", "plplotluacLUA__wrap_8c.html#a17a66293ab9834fe0bea873a52989305", null ],
    [ "_wrap_scmap1a", "plplotluacLUA__wrap_8c.html#a4dd4eea7529b4938d178e05464ed55a0", null ],
    [ "_wrap_scmap1l", "plplotluacLUA__wrap_8c.html#adf3176d02c5e68cbcb7417c0c2743545", null ],
    [ "_wrap_scmap1la", "plplotluacLUA__wrap_8c.html#a6b7fff67553bcb4f955cd4d59830fd49", null ],
    [ "_wrap_scmap1n", "plplotluacLUA__wrap_8c.html#a46819f7d7b9cbf503008ff14c142b225", null ],
    [ "_wrap_scol0", "plplotluacLUA__wrap_8c.html#af6aa86cd682ccd0abf37ea2227734e7c", null ],
    [ "_wrap_scol0a", "plplotluacLUA__wrap_8c.html#a82e3cb6d42e84ec61f7a6ec4b8251dcd", null ],
    [ "_wrap_scolbg", "plplotluacLUA__wrap_8c.html#a9042b0a72035e4f7deb21db3dd9be2a5", null ],
    [ "_wrap_scolbga", "plplotluacLUA__wrap_8c.html#a696150e6346a935b856d2f05a029554a", null ],
    [ "_wrap_scolor", "plplotluacLUA__wrap_8c.html#a97567aaf727a903671a19ea0628a9371", null ],
    [ "_wrap_scompression", "plplotluacLUA__wrap_8c.html#af560577fb0f48ae250f80d065ea2226d", null ],
    [ "_wrap_sdev", "plplotluacLUA__wrap_8c.html#ac14437b813ab7f1eb8ddf2f9a183ef82", null ],
    [ "_wrap_sdidev", "plplotluacLUA__wrap_8c.html#a46065e8d3e8c9d1f56ed02b63cca7038", null ],
    [ "_wrap_sdimap", "plplotluacLUA__wrap_8c.html#a48d5777d2a2b936cba2a4f41c9bf4635", null ],
    [ "_wrap_sdiori", "plplotluacLUA__wrap_8c.html#af7e20a163982164ed2bdfa5d72178112", null ],
    [ "_wrap_sdiplt", "plplotluacLUA__wrap_8c.html#a30ed985323345f156ff3a0be664e515d", null ],
    [ "_wrap_sdiplz", "plplotluacLUA__wrap_8c.html#ad8cd2adc7a3543ac840d0d2331638bc2", null ],
    [ "_wrap_seed", "plplotluacLUA__wrap_8c.html#a304094ebcb39d1e468c1e4f748a7f9e5", null ],
    [ "_wrap_sesc", "plplotluacLUA__wrap_8c.html#af6e8543f184b502dfb54cee46d84a2c7", null ],
    [ "_wrap_setcontlabelformat", "plplotluacLUA__wrap_8c.html#a46d07b36fa0428acdeb1c743bc22c665", null ],
    [ "_wrap_setcontlabelparam", "plplotluacLUA__wrap_8c.html#a354705cd526685abeb8a274433014cc6", null ],
    [ "_wrap_setopt", "plplotluacLUA__wrap_8c.html#ad195f2409c0b375763f94d0fac3326ea", null ],
    [ "_wrap_sfam", "plplotluacLUA__wrap_8c.html#a7c0f373c82e1d7e982a8f7c8169e28bf", null ],
    [ "_wrap_sfci", "plplotluacLUA__wrap_8c.html#a58d4514e342f9ce90cf73cac0056ef97", null ],
    [ "_wrap_sfnam", "plplotluacLUA__wrap_8c.html#adc1c2d4dd85b5d281eb656e075649d8c", null ],
    [ "_wrap_sfont", "plplotluacLUA__wrap_8c.html#a5dc098f22f4e893f730b8f85f94dab18", null ],
    [ "_wrap_shade", "plplotluacLUA__wrap_8c.html#a599b65c281899514917f47bafbd586a7", null ],
    [ "_wrap_shades", "plplotluacLUA__wrap_8c.html#ad1a48837e65771bf09fca596e6243375", null ],
    [ "_wrap_slabelfunc", "plplotluacLUA__wrap_8c.html#a6bc22ce016078ab96a31f61b32126dcf", null ],
    [ "_wrap_smaj", "plplotluacLUA__wrap_8c.html#aab3fb3ce702ed6a5268eebe6c3bc4690", null ],
    [ "_wrap_smin", "plplotluacLUA__wrap_8c.html#acc089f6dab502cf0bbc0c630ffca320a", null ],
    [ "_wrap_sori", "plplotluacLUA__wrap_8c.html#a0c0e003ffc8d3d78c4864d66141ca92e", null ],
    [ "_wrap_spage", "plplotluacLUA__wrap_8c.html#a124cad43f905862ef76785256c055d4c", null ],
    [ "_wrap_spal0", "plplotluacLUA__wrap_8c.html#ac7b3a92201cf094bda4078acfaecd673", null ],
    [ "_wrap_spal1", "plplotluacLUA__wrap_8c.html#ac5f6f823f16c40f77461e392e867b078", null ],
    [ "_wrap_spause", "plplotluacLUA__wrap_8c.html#a425f9432f46a7bdc92c87c973f3f5bf3", null ],
    [ "_wrap_sstrm", "plplotluacLUA__wrap_8c.html#a75e65658bb5162f25a2337e1d2ffa763", null ],
    [ "_wrap_ssub", "plplotluacLUA__wrap_8c.html#a4d6c8734921abae8731b47f537241e48", null ],
    [ "_wrap_ssym", "plplotluacLUA__wrap_8c.html#a2720e66f555801d49f00ffd6e04fd89a", null ],
    [ "_wrap_star", "plplotluacLUA__wrap_8c.html#a83241a70442f0c82f48784af9bcfee76", null ],
    [ "_wrap_start", "plplotluacLUA__wrap_8c.html#aad77801da31f1d4799a529b84a3fac19", null ],
    [ "_wrap_stransform", "plplotluacLUA__wrap_8c.html#a95e61f99ad21d5c727f77ea0c4851e8a", null ],
    [ "_wrap_string", "plplotluacLUA__wrap_8c.html#aa670a7d51dbbe7c945555db6b36fe715", null ],
    [ "_wrap_string3", "plplotluacLUA__wrap_8c.html#ac5cf74c6c9795e966b79d1d883609749", null ],
    [ "_wrap_stripa", "plplotluacLUA__wrap_8c.html#aa2ae0035232de2a05edc3a8b45d31a70", null ],
    [ "_wrap_stripc", "plplotluacLUA__wrap_8c.html#a733a0e78282b782f22fecc37eecfcabd", null ],
    [ "_wrap_stripd", "plplotluacLUA__wrap_8c.html#af3cab3a51af1b0257210908fa4e823a1", null ],
    [ "_wrap_styl", "plplotluacLUA__wrap_8c.html#ad98944d73d53d47f99727937d710ff63", null ],
    [ "_wrap_surf3d", "plplotluacLUA__wrap_8c.html#ac744cf5e0c1a4b633062486a4f0155d7", null ],
    [ "_wrap_surf3dl", "plplotluacLUA__wrap_8c.html#a02523ec2c52bc6134a20dc6f1a78170a", null ],
    [ "_wrap_svect", "plplotluacLUA__wrap_8c.html#a8146979ec05c212259013215eb3e1f45", null ],
    [ "_wrap_svpa", "plplotluacLUA__wrap_8c.html#aec6d47ca8d9fc6817dc4760cd34abab9", null ],
    [ "_wrap_sxax", "plplotluacLUA__wrap_8c.html#af2af9bf4178dcaa2e471c0e7cf85bb3a", null ],
    [ "_wrap_syax", "plplotluacLUA__wrap_8c.html#af4c4469105306a961b79a6e3f8be6b3e", null ],
    [ "_wrap_sym", "plplotluacLUA__wrap_8c.html#a3ec030b575ef69ca3ce9b1f06e74fa42", null ],
    [ "_wrap_szax", "plplotluacLUA__wrap_8c.html#a04a47031bf6ef45ab88cd449ef2abc51", null ],
    [ "_wrap_text", "plplotluacLUA__wrap_8c.html#a399bac734b6119024345a4fc54bd0f38", null ],
    [ "_wrap_timefmt", "plplotluacLUA__wrap_8c.html#a7060676e641422a5db4a7f799f1078c7", null ],
    [ "_wrap_vasp", "plplotluacLUA__wrap_8c.html#a8e03ef1da5b551053f2de2a677718338", null ],
    [ "_wrap_vect", "plplotluacLUA__wrap_8c.html#acffb8e203a3b2bb79cbdd06323536e61", null ],
    [ "_wrap_vpas", "plplotluacLUA__wrap_8c.html#aef470ea1e35ecf52f6b4b7f0a1002fdf", null ],
    [ "_wrap_vpor", "plplotluacLUA__wrap_8c.html#a3c0ea3999f7660a817b568f659d4e8d1", null ],
    [ "_wrap_vsta", "plplotluacLUA__wrap_8c.html#adb659b56cf89a59fda767d2a1d5edb93", null ],
    [ "_wrap_w3d", "plplotluacLUA__wrap_8c.html#a93e784a42f201ecc886a610bbecd13bc", null ],
    [ "_wrap_warn", "plplotluacLUA__wrap_8c.html#a9c7ae561c11bc25406a1de13df017d98", null ],
    [ "_wrap_width", "plplotluacLUA__wrap_8c.html#a37c27d425b0dd8bb22bd40b451390f06", null ],
    [ "_wrap_wind", "plplotluacLUA__wrap_8c.html#a059156ef04b3bb9102cadc3c898c3d4a", null ],
    [ "_wrap_xormod", "plplotluacLUA__wrap_8c.html#a40dbe95b2be422f2476a5375606f6eb4", null ],
    [ "LUA_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#a8c16dccb10308adfacc5fffd46e21e04", null ],
    [ "LUA_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#ad67fd18f3472dadb9be9853c6ae2b7c9", null ],
    [ "mapform", "plplotluacLUA__wrap_8c.html#a76fa5082c51c2ab5ddbed707104cea4b", null ],
    [ "myct", "plplotluacLUA__wrap_8c.html#a243c977a3ddb518317f279667ab8fb11", null ],
    [ "myct", "plplotluacLUA__wrap_8c.html#ab1d13ab7012711b196048690b4f5029b", null ],
    [ "mylabel", "plplotluacLUA__wrap_8c.html#a0a4039722bda7e468ee6ac8ce1695bbe", null ],
    [ "mylabel", "plplotluacLUA__wrap_8c.html#aee7e47a9971e622954d7ef47c6ddda91", null ],
    [ "mypltr", "plplotluacLUA__wrap_8c.html#a37ac56130680a70dc463cb4f8be424a4", null ],
    [ "mypltr", "plplotluacLUA__wrap_8c.html#aff4212f07531ac5df5b9c672a4107805", null ],
    [ "read_double_Matrix", "plplotluacLUA__wrap_8c.html#a03fbc9a75a0be1fa43da9accc215aab2", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#a42bc3512a1ef24091c0c273417224ee3", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#ac104aafd2f70d3d19824556c997f9caf", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#ae852c117c9d1c13b70866dd8fb67b593", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#ab3ce42414151f5f4f9cbcd41ef6886b6", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#a2cbf0b1e4c8fd24c708294e83b0ee3a5", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#a7a1fc50e11e42a71a8dee629a7f1785f", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#a0d88adae3ef55fb41f1dec8bf90261db", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#a489d300deb24eb589f15b365a5073f62", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#aa071122d35ed11fac1fee8b2a7dc778d", null ],
    [ "SWIG_DECLARE_TYPEMAP_ARR_FN", "plplotluacLUA__wrap_8c.html#a3d1cf7688ac7c177746131b5fb08185a", null ],
    [ "swig_delete_PLGraphicsIn", "plplotluacLUA__wrap_8c.html#aa4718789ad19abac282fbdbe0c391772", null ],
    [ "SWIG_get_ptr_array_fixed", "plplotluacLUA__wrap_8c.html#a7f5b7c64e30854e265c6e146885fe4da", null ],
    [ "SWIG_get_ptr_array_var", "plplotluacLUA__wrap_8c.html#a4ec94120cb85d08fb0c93149c38d04eb", null ],
    [ "SWIG_init", "plplotluacLUA__wrap_8c.html#ae47dcf5ac0f3c7237fa5894034438af9", null ],
    [ "SWIG_init_user", "plplotluacLUA__wrap_8c.html#a9d4e8042e1aeb7517f6e70b5b37269c9", null ],
    [ "SWIG_InitializeModule", "plplotluacLUA__wrap_8c.html#a7f8da48fe4dbc23aef01a714623b8a6b", null ],
    [ "SWIG_itable_size", "plplotluacLUA__wrap_8c.html#a6e0b3731cc48dd5ee179491ca42b2785", null ],
    [ "SWIG_Lua_add_class_details", "plplotluacLUA__wrap_8c.html#aa82840b8b3ce37d1cf1e3c3aa1bc6beb", null ],
    [ "SWIG_Lua_add_class_static_details", "plplotluacLUA__wrap_8c.html#a893afdb43641c6f2a334bc28b2bc5d90", null ],
    [ "SWIG_Lua_add_class_variable", "plplotluacLUA__wrap_8c.html#a199fa578fb0309b79b5ed51844c590ad", null ],
    [ "SWIG_Lua_add_namespace_details", "plplotluacLUA__wrap_8c.html#a9ee5ba0a0bf072010a447d4b2f98d545", null ],
    [ "SWIG_Lua_class_destruct", "plplotluacLUA__wrap_8c.html#aba87e0d4ef2c7e61e81b4f685eef7b7b", null ],
    [ "SWIG_Lua_class_disown", "plplotluacLUA__wrap_8c.html#aa6dab0ada88ba05ba8067207c79efbd8", null ],
    [ "SWIG_Lua_class_get", "plplotluacLUA__wrap_8c.html#a85b5ba6bf2bdbe0d21a3611f3b5f8df3", null ],
    [ "SWIG_Lua_class_register", "plplotluacLUA__wrap_8c.html#a96a75364a5f20fd525bb603440f698d3", null ],
    [ "SWIG_Lua_class_register_static", "plplotluacLUA__wrap_8c.html#a2451693ac83d6d677ab826b113491760", null ],
    [ "SWIG_Lua_class_set", "plplotluacLUA__wrap_8c.html#ab75aeed852fd5b630a45dd2312ced041", null ],
    [ "SWIG_Lua_class_tostring", "plplotluacLUA__wrap_8c.html#aeabb40f074f78d6ff46831b93e4750e1", null ],
    [ "SWIG_Lua_constructor_proxy", "plplotluacLUA__wrap_8c.html#aa6b2b3e8c34678d30d3a95d5026681b6", null ],
    [ "SWIG_Lua_ConvertPacked", "plplotluacLUA__wrap_8c.html#a34313b58896afa8f8a27f1d0bfd2b7c4", null ],
    [ "SWIG_Lua_ConvertPtr", "plplotluacLUA__wrap_8c.html#a0d0394796468d0001b1d3d358a19891f", null ],
    [ "SWIG_Lua_dostring", "plplotluacLUA__wrap_8c.html#a3af0c40da7cc32dc9af81d722828ad63", null ],
    [ "SWIG_Lua_equal", "plplotluacLUA__wrap_8c.html#a19beacd0425081097301c85934140c9e", null ],
    [ "SWIG_Lua_get_class_metatable", "plplotluacLUA__wrap_8c.html#af93e8f0a3beec1aefa768abb89fe7485", null ],
    [ "SWIG_Lua_get_class_registry", "plplotluacLUA__wrap_8c.html#a882b457b337f778c6925c77b59cbae79", null ],
    [ "SWIG_Lua_GetModule", "plplotluacLUA__wrap_8c.html#aa7e1ff7a89ff12ee84b36802220fae51", null ],
    [ "SWIG_Lua_init_base_class", "plplotluacLUA__wrap_8c.html#ac765a0526209ac87f7e209669ce959d0", null ],
    [ "SWIG_Lua_InstallConstants", "plplotluacLUA__wrap_8c.html#af6d78a7441d3788ad73c978698a0cc1e", null ],
    [ "SWIG_lua_isnilstring", "plplotluacLUA__wrap_8c.html#ab7871721020ea2772e868431a74be4fa", null ],
    [ "SWIG_Lua_module_add_function", "plplotluacLUA__wrap_8c.html#a932b10d589ac13b4a690832ed849c0b0", null ],
    [ "SWIG_Lua_module_add_variable", "plplotluacLUA__wrap_8c.html#a50b33f6146893cce0503ee05c2ff6861", null ],
    [ "SWIG_Lua_module_begin", "plplotluacLUA__wrap_8c.html#aeec0e64e8f688529897d5d4deafd80b1", null ],
    [ "SWIG_Lua_module_end", "plplotluacLUA__wrap_8c.html#ade1d6e13cbfde4ae68e337d558004ee1", null ],
    [ "SWIG_Lua_module_get", "plplotluacLUA__wrap_8c.html#adac9c2918f945c6a24bde2e4fecf9f70", null ],
    [ "SWIG_Lua_module_set", "plplotluacLUA__wrap_8c.html#a8bb6f0983ff06b1c171f90d0009e9eba", null ],
    [ "SWIG_Lua_MustGetPtr", "plplotluacLUA__wrap_8c.html#a8ed84d67fe041f17069ed2e28e23d1e4", null ],
    [ "SWIG_Lua_namespace_get", "plplotluacLUA__wrap_8c.html#a82a3c5d46b7bdaa57cc1106ff5a89663", null ],
    [ "SWIG_Lua_namespace_register", "plplotluacLUA__wrap_8c.html#a8600fb5860a603c15d18321afd3b910a", null ],
    [ "SWIG_Lua_namespace_set", "plplotluacLUA__wrap_8c.html#aa56ce48dad661ece0586e2b0477d04d6", null ],
    [ "SWIG_Lua_NewPackedObj", "plplotluacLUA__wrap_8c.html#ab98924e8e52ff8f34ace1515120ccda6", null ],
    [ "SWIG_Lua_NewPointerObj", "plplotluacLUA__wrap_8c.html#a96c4cba9e0940983c98de6a9d6f339c8", null ],
    [ "SWIG_Lua_pusherrstring", "plplotluacLUA__wrap_8c.html#a17d5e7cfbab0914882ec82e36d22381e", null ],
    [ "SWIG_Lua_pushferrstring", "plplotluacLUA__wrap_8c.html#ad4708a823127d389179291ebcace732d", null ],
    [ "SWIG_Lua_set_immutable", "plplotluacLUA__wrap_8c.html#a98115a70232aa660ee341e0ea4353485", null ],
    [ "SWIG_Lua_SetModule", "plplotluacLUA__wrap_8c.html#a127abd2d6d37e5b1e86d2421c751492e", null ],
    [ "SWIG_Lua_type", "plplotluacLUA__wrap_8c.html#a85bb429fb2e29e3681bbda49ce8c34c1", null ],
    [ "SWIG_Lua_typename", "plplotluacLUA__wrap_8c.html#a3ebd284134ee5f4877fe86f646aebde6", null ],
    [ "SWIG_MangledTypeQueryModule", "plplotluacLUA__wrap_8c.html#ac63ad9b58a96793188f944c92ff40ec6", null ],
    [ "SWIG_PackData", "plplotluacLUA__wrap_8c.html#a02c2ac3db8ce87dd62813334e66c9a3a", null ],
    [ "SWIG_PackDataName", "plplotluacLUA__wrap_8c.html#af903e6809a1fb2ba06deff49795c6e65", null ],
    [ "SWIG_PackVoidPtr", "plplotluacLUA__wrap_8c.html#a10c5572eb6206df7c95c8a2fcde90911", null ],
    [ "SWIG_PropagateClientData", "plplotluacLUA__wrap_8c.html#abc08944d526c952dc121d3d1b84f0d16", null ],
    [ "SWIG_read_ptr_array", "plplotluacLUA__wrap_8c.html#ab2ef582cb8ec66b9c8cf858f2f3fd973", null ],
    [ "SWIG_table_size", "plplotluacLUA__wrap_8c.html#ad7dcbf32765ed34c96ff33f69180f0d5", null ],
    [ "SWIG_TypeCast", "plplotluacLUA__wrap_8c.html#a334486cb1e8f569c949a0384cbdb2a16", null ],
    [ "SWIG_TypeCheck", "plplotluacLUA__wrap_8c.html#abd0cb78a9663e41312c8f14ab6715f04", null ],
    [ "SWIG_TypeCheckStruct", "plplotluacLUA__wrap_8c.html#a898a1dfcdf96d53a2c7fd90e8500b36e", null ],
    [ "SWIG_TypeClientData", "plplotluacLUA__wrap_8c.html#a4b0a40223812f7d43bc2f0c2342fe2f7", null ],
    [ "SWIG_TypeCmp", "plplotluacLUA__wrap_8c.html#a73131c439c907ed987c34da85b95a597", null ],
    [ "SWIG_TypeDynamicCast", "plplotluacLUA__wrap_8c.html#add8cb1a47628b36915ffa37d61452b1e", null ],
    [ "SWIG_TypeEquiv", "plplotluacLUA__wrap_8c.html#a23ecf039d651082ffc7582c4f50af780", null ],
    [ "SWIG_TypeName", "plplotluacLUA__wrap_8c.html#a68560e0bf641c9691704d6d05bac4358", null ],
    [ "SWIG_TypeNameComp", "plplotluacLUA__wrap_8c.html#a2f69ad4207037cb391a2b2d5915fcba2", null ],
    [ "SWIG_TypeNewClientData", "plplotluacLUA__wrap_8c.html#a710082a7ea6978d654bad712dbebc0ee", null ],
    [ "SWIG_TypePrettyName", "plplotluacLUA__wrap_8c.html#a3f38ea686cb3f85bf6a15b08416f2684", null ],
    [ "SWIG_TypeQueryModule", "plplotluacLUA__wrap_8c.html#a5b6a2719f95288678fa55ade4493b175", null ],
    [ "SWIG_UnpackData", "plplotluacLUA__wrap_8c.html#a80e9e66f66413297452de92c69cdf9d7", null ],
    [ "SWIG_UnpackDataName", "plplotluacLUA__wrap_8c.html#a99540d89d9ffca957892cf22af3e49dd", null ],
    [ "SWIG_UnpackVoidPtr", "plplotluacLUA__wrap_8c.html#ae3e13f3464cb74f7e5d9f7a50a6855c0", null ],
    [ "SWIG_write_ptr_array", "plplotluacLUA__wrap_8c.html#a3545baaca21634ea1a51ab9e5f43c42c", null ],
    [ "_swigc__p_char", "plplotluacLUA__wrap_8c.html#a8848127146fe0444e2fe3183a15b67f5", null ],
    [ "_swigc__p_double", "plplotluacLUA__wrap_8c.html#a28b7f0e03111f37524cf093e3a8a2304", null ],
    [ "_swigc__p_f_double_double__int", "plplotluacLUA__wrap_8c.html#a207f66749bdba90b94fc94339a002520", null ],
    [ "_swigc__p_f_double_double_p_double_p_double_p_void__void", "plplotluacLUA__wrap_8c.html#a3f4c37068cdd295d0dafa913f043216e", null ],
    [ "_swigc__p_f_int_double_p_char_int_p_void__void", "plplotluacLUA__wrap_8c.html#abd7eee4930f48e2326a9df35e20f0bba", null ],
    [ "_swigc__p_f_int_p_double_p_double__void", "plplotluacLUA__wrap_8c.html#a5c2379fb009e6c97a5de4731c20e4283", null ],
    [ "_swigc__p_f_int_p_q_const__double_p_q_const__double__void", "plplotluacLUA__wrap_8c.html#af6625b2b7918b35eddbed9053fad7905", null ],
    [ "_swigc__p_int", "plplotluacLUA__wrap_8c.html#a216d8b24b856092e2e65830ef290159b", null ],
    [ "_swigc__p_p_char", "plplotluacLUA__wrap_8c.html#adf82b09513b48dd2275acc2fa74711b7", null ],
    [ "_swigc__p_p_double", "plplotluacLUA__wrap_8c.html#a8ef572e7214cb0eedcc6419377664472", null ],
    [ "_swigc__p_PLGraphicsIn", "plplotluacLUA__wrap_8c.html#adbc9470f42e7e3c0a2adab2df09b950d", null ],
    [ "_swigc__p_unsigned_int", "plplotluacLUA__wrap_8c.html#aba9e61dc970ecfa60bf8a90276b1daa9", null ],
    [ "_swigt__p_char", "plplotluacLUA__wrap_8c.html#ae66f44191f70db7b9634a8321766c840", null ],
    [ "_swigt__p_double", "plplotluacLUA__wrap_8c.html#a650096f8d16b87549437da125768b407", null ],
    [ "_swigt__p_f_double_double__int", "plplotluacLUA__wrap_8c.html#aa99dba7c5dc196a6edb638363e104be7", null ],
    [ "_swigt__p_f_double_double_p_double_p_double_p_void__void", "plplotluacLUA__wrap_8c.html#a169d330528354eea0e80046288f7a240", null ],
    [ "_swigt__p_f_int_double_p_char_int_p_void__void", "plplotluacLUA__wrap_8c.html#ad192a829bb4110f62a13c396ab965321", null ],
    [ "_swigt__p_f_int_p_double_p_double__void", "plplotluacLUA__wrap_8c.html#ac93b2bfcffa54c72401ce0fe924336ef", null ],
    [ "_swigt__p_f_int_p_q_const__double_p_q_const__double__void", "plplotluacLUA__wrap_8c.html#a8a3b05af198a366e7d91148da9aa0695", null ],
    [ "_swigt__p_int", "plplotluacLUA__wrap_8c.html#abb18e7711ddb7deeaf40f89dd6643b2c", null ],
    [ "_swigt__p_p_char", "plplotluacLUA__wrap_8c.html#a701773c68706ee07319dc186a10ec151", null ],
    [ "_swigt__p_p_double", "plplotluacLUA__wrap_8c.html#a7142a8246b533266bb0a1ec0e07d0516", null ],
    [ "_swigt__p_PLGraphicsIn", "plplotluacLUA__wrap_8c.html#aa7423ef65fc1e3d9cc8e9acb90b31531", null ],
    [ "_swigt__p_unsigned_int", "plplotluacLUA__wrap_8c.html#ac758895aa5c2bb2a384d76af7fc77b2c", null ],
    [ "_wrap_class_PLGraphicsIn", "plplotluacLUA__wrap_8c.html#af535aeb8e20ec55a72edebec41daf497", null ],
    [ "Alen", "plplotluacLUA__wrap_8c.html#a27d25ac7e864031d461a8a5460144223", null ],
    [ "mapform_funcstr", "plplotluacLUA__wrap_8c.html#a94a9dec6cb94efe1b6781d5151c6c983", null ],
    [ "myct_funcstr", "plplotluacLUA__wrap_8c.html#aa5ede8a2565e24ed4df2e0896f47036c", null ],
    [ "myL", "plplotluacLUA__wrap_8c.html#a9917af03e350a440311193fb9099c720", null ],
    [ "mylabel_funcstr", "plplotluacLUA__wrap_8c.html#a5797cce2266cabb8bc8f22e3c212fb2c", null ],
    [ "mypltr_funcstr", "plplotluacLUA__wrap_8c.html#a6abec419e8ef65ee5b90b45b293654ae", null ],
    [ "swig_cast_initial", "plplotluacLUA__wrap_8c.html#a0666e347f7d486a3bc82b78efd732333", null ],
    [ "swig_commands", "plplotluacLUA__wrap_8c.html#a81939268e0c5a2bcdc5b85a2b81af578", null ],
    [ "swig_constants", "plplotluacLUA__wrap_8c.html#ad6cf4679bcd945976329a7a2322eb933", null ],
    [ "SWIG_LUACODE", "plplotluacLUA__wrap_8c.html#aa51daa176c79b3ddc28ddd7faea49df6", null ],
    [ "swig_module", "plplotluacLUA__wrap_8c.html#a5f41f6e106d3195e660a39e5292f50fd", null ],
    [ "swig_PLGraphicsIn_attributes", "plplotluacLUA__wrap_8c.html#a31ea4233864be17d7c1522edd94cae04", null ],
    [ "swig_PLGraphicsIn_base_names", "plplotluacLUA__wrap_8c.html#a61ee77e649c977070ca543d7c915c4dd", null ],
    [ "swig_PLGraphicsIn_bases", "plplotluacLUA__wrap_8c.html#a628bc42b3766b1f707c39d4744799c70", null ],
    [ "swig_PLGraphicsIn_cls_attributes", "plplotluacLUA__wrap_8c.html#a3fa85ddbe4f32bc9793de6ecb8aa915a", null ],
    [ "swig_PLGraphicsIn_cls_constants", "plplotluacLUA__wrap_8c.html#a8d528cee4f8bfb79408fa2a9a6a7ad6d", null ],
    [ "swig_PLGraphicsIn_cls_methods", "plplotluacLUA__wrap_8c.html#a246a673ec285a0ba6a7d8f03ab3bbb05", null ],
    [ "swig_PLGraphicsIn_methods", "plplotluacLUA__wrap_8c.html#ae99b2700e57e59871b8f487565d83c73", null ],
    [ "swig_type_initial", "plplotluacLUA__wrap_8c.html#ad621c8a05a43cf3a48467c791142bb44", null ],
    [ "swig_types", "plplotluacLUA__wrap_8c.html#a5a4358414fc0b190c3d0255e2d5d4ca2", null ],
    [ "swig_variables", "plplotluacLUA__wrap_8c.html#af3bb62e270edaa3cc9bfcff5e8a6b143", null ],
    [ "Xlen", "plplotluacLUA__wrap_8c.html#ac91c25f032882cfbd3e877adb9dd788d", null ],
    [ "Ylen", "plplotluacLUA__wrap_8c.html#a63da9b8b39f2bb3fdf520fdc1dd0870a", null ]
];